@@ -1,17 +1,12 @@
-import importlib
 import os
 import time
 import unittest
 
-import testcase.state_testing_app.app_constants
-from testcase.state_testing_app.app_constants import constants
 from testcase.state_testing_app.app_lambda import lambda_handler
 
 
 class TestStateMixin(unittest.TestCase):
     def test_state_mixin(self):
-        importlib.reload(constants)
-        importlib.reload(testcase.state_testing_app.app_constants)
         asset_id = 29399830
 
         os.environ["LOGGING_ASSET_ID"] = str(asset_id)
@@ -22,9 +17,9 @@ class TestStateMixin(unittest.TestCase):
             "timestamp": 2
         }]
         start_timer = time.time()
+
+        # loading of constants should happen here to avoid conflicts
+        # although this import is unused but it is required to reset the constants
+        from testcase.state_testing_app.app_constants import constants  # noqa: F401
         lambda_handler(event, None)
         print(f"Finished testing StateMixin in {int(time.time() - start_timer)} seconds.")
-
-
-if __name__ == '__main__':
-    unittest.main()
