@@ -115,7 +115,7 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         time_modules = [module for module in self.get_modules() if issubclass(module, TimeActivityModule)]
         maximum_lookback = 0
         for module in time_modules:
-            module_lookback = constants.get('{}.{}.export-duration'.format(self.app_key, module.module_key), default=0)
+            module_lookback = constants.get('{}.{}.lookback-duration'.format(self.app_key, module.module_key), default=0)
             maximum_lookback = max(module_lookback, maximum_lookback)
 
         return maximum_lookback
