@@ -22,6 +22,8 @@ class Module(StateMixin, LoggingMixin, RollbarMixin):
         'last_processed_timestamp': int
     }
 
+    enabled = True
+
     def __init__(self, global_state, *args, **kwargs):
         self.app_key = constants.get('global.app-key')
         self.app_name = constants.get('global.app-name')
@@ -219,12 +221,3 @@ class Module(StateMixin, LoggingMixin, RollbarMixin):
     def format_output(output):
         output = json.dumps(output)
         return output
-
-    @staticmethod
-    def compute_timestep(dataset: list):
-        if len(dataset) < 2:
-            return None
-
-        timestep = (dataset[-1].get('timestamp') - dataset[0].get('timestamp')) / (len(dataset) - 1)
-
-        return timestep
